summaryrefslogtreecommitdiffstats
path: root/kmobile/kioslave/kio_mobile.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kmobile/kioslave/kio_mobile.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmobile/kioslave/kio_mobile.cpp')
-rw-r--r--kmobile/kioslave/kio_mobile.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/kmobile/kioslave/kio_mobile.cpp b/kmobile/kioslave/kio_mobile.cpp
index 5cf5bed5..b22930e2 100644
--- a/kmobile/kioslave/kio_mobile.cpp
+++ b/kmobile/kioslave/kio_mobile.cpp
@@ -78,7 +78,7 @@ KMobileProtocol::~KMobileProtocol()
}
/*
- * getDeviceAndRessource("mobile:/<devicename>/<resource>/...") - split
+ * getDeviceAndRessource("mobile:/<tqdevicename>/<resource>/...") - split
*/
int KMobileProtocol::getDeviceAndRessource(const TQString &_path,
TQString &devName, TQString &resource, TQString &devPath,
@@ -87,7 +87,7 @@ int KMobileProtocol::getDeviceAndRessource(const TQString &_path,
// PRINT_DEBUG << TQString("###getDeviceAndRessource### %1\n").arg(_path);
TQStringList path = TQStringList::split('/', _path, false);
- devName = resource = devPath = TQString::null;
+ devName = resource = devPath = TQString();
devCaps = KMobileDevice::hasNothing;
if (path.count() >= 1) { devName = path[0]; path.pop_front(); };
@@ -120,7 +120,7 @@ int KMobileProtocol::getDeviceAndRessource(const TQString &_path,
static
-void addAtom(KIO::UDSEntry& entry, unsigned int ID, long l, const TQString& s = TQString::null)
+void addAtom(KIO::UDSEntry& entry, unsigned int ID, long l, const TQString& s = TQString())
{
KIO::UDSAtom atom;
atom.m_uds = ID;
@@ -227,7 +227,7 @@ void KMobileProtocol::get(const KURL &url)
/*
- * listRoot() - gives listing of all devices
+ * listRoot() - gives listing of all tqdevices
*/
void KMobileProtocol::listRoot(const KURL& url)
{
@@ -235,8 +235,8 @@ void KMobileProtocol::listRoot(const KURL& url)
KIO::UDSEntry entry;
- TQStringList deviceNames = m_dev.deviceNames();
- unsigned int dirs = deviceNames.count();
+ TQStringList tqdeviceNames = m_dev.tqdeviceNames();
+ unsigned int dirs = tqdeviceNames.count();
totalSize(dirs);
int classMask = KMobileDevice::Unclassified;
@@ -251,14 +251,14 @@ void KMobileProtocol::listRoot(const KURL& url)
for (unsigned int i=0; i<dirs; i++) {
- TQString devName = deviceNames[i];
+ TQString devName = tqdeviceNames[i];
if (classMask != KMobileDevice::Unclassified &&
m_dev.classType(devName) != classMask)
continue;
createDirEntry(entry, devName, "mobile:/"+devName,
- KMOBILE_MIMETYPE_DEVICE_KONQUEROR(devName));
+ KMOBILE_MIMETYPE_DEVICE_KONTQUEROR(devName));
listEntry(entry, false);
processedSize(i+1);
@@ -307,7 +307,7 @@ TQString KMobileProtocol::entryMimeType(int cap)
}
/*
- * listTopDeviceDir("mobile:/<devicename>") - sub-directory of a devices
+ * listTopDeviceDir("mobile:/<tqdevicename>") - sub-directory of a tqdevices
*/
void KMobileProtocol::listTopDeviceDir(const TQString &devName)
@@ -334,7 +334,7 @@ void KMobileProtocol::listTopDeviceDir(const TQString &devName)
/*
* listEntries("mobile:/<devicename>/<resource>") - resources of a device
*/
void KMobileProtocol::listEntries(const TQString &devName,
const TQString &resource, const TQString &devPath,
@@ -356,7 +356,7 @@ void KMobileProtocol::listEntries(const TQString &devName,
}
/*
- * listAddressBook("mobile:/<devicename>/Addressbook) - list the addressbook
+ * listAddressBook("mobile:/<tqdevicename>/Addressbook) - list the addressbook
*/
void KMobileProtocol::listAddressBook(const TQString &devName, const TQString &resource)
{
@@ -377,7 +377,7 @@ void KMobileProtocol::listAddressBook(const TQString &devName, const TQString &r
#if 0
TQString content = m_dev.readAddress(devName, i);
if ( rx.search( content ) < 0 )
- name = TQString::null;
+ name = TQString();
else
name = "_" + rx.cap(1);
#endif
@@ -405,7 +405,7 @@ int KMobileProtocol::getVCard( const TQString &devName, TQCString &result, TQStr
{
PRINT_DEBUG << TQString("getVCard(%1)\n").arg(path);
- int index = path.find('.');
+ int index = path.tqfind('.');
if (index>0)
index = path.left(index).toInt();
if (index<0 || index>=m_dev.numAddresses(devName))
@@ -421,7 +421,7 @@ int KMobileProtocol::getVCard( const TQString &devName, TQCString &result, TQStr
}
/*
- * listCalendar("mobile:/<devicename>/Calendar) - list the calendar entries
+ * listCalendar("mobile:/<tqdevicename>/Calendar) - list the calendar entries
*/
void KMobileProtocol::listCalendar( const TQString &devName, const TQString &resource)
{
@@ -460,7 +460,7 @@ int KMobileProtocol::getCalendar( const TQString &devName, TQCString &result, TQ
/*
- * listNotes("mobile:/<devicename>/Notes) - list the notes
+ * listNotes("mobile:/<tqdevicename>/Notes) - list the notes
*/
void KMobileProtocol::listNotes( const TQString &devName, const TQString &resource)
{
@@ -494,7 +494,7 @@ int KMobileProtocol::getNote( const TQString &devName, TQCString &result, TQStri
{
PRINT_DEBUG << TQString("getNote(%1)\n").arg(path);
- int index = path.find('_');
+ int index = path.tqfind('_');
if (index>0)
index = path.left(index).toInt();
if (index<0 || index>=m_dev.numNotes(devName))
@@ -510,7 +510,7 @@ int KMobileProtocol::getNote( const TQString &devName, TQCString &result, TQStri
}
/*
* listFileStorage("mobile:/<devicename>/Files) - list the files on the device
*/
void KMobileProtocol::listFileStorage(const TQString &devName, const TQString &resource, const TQString &devPath)
{
@@ -536,7 +536,7 @@ int KMobileProtocol::getFileStorage(const TQString &devName, TQCString &result,
/**
- * Test if the url tqcontains a directory or a file.
+ * Test if the url contains a directory or a file.
*/
void KMobileProtocol::stat( const KURL &url )
{
@@ -334,7 +334,7 @@ void KMobileProtocol::listTopDeviceDir(const TQString &devName)
/*
- * listEntries("mobile:/<devicename>/<resource>") - resources of a device
+ * listEntries("mobile:/<tqdevicename>/<resource>") - resources of a tqdevice
*/
void KMobileProtocol::listEntries(const TQString &devName,
@@ -510,7 +510,7 @@ int KMobileProtocol::getNote( const TQString &devName, TQCString &result, TQStri
}
/*
- * listFileStorage("mobile:/<devicename>/Files) - list the files on the device
+ * listFileStorage("mobile:/<tqdevicename>/Files) - list the files on the tqdevice
*/
void KMobileProtocol::listFileStorage(const TQString &devName, const TQString &resource, const TQString &devPath)